<TS language="nb" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Om Gridcoin</translation>
    </message>
    <message>
        <source>&lt;b&gt;Gridcoin&lt;/b&gt; </source>
        <translation>&lt;b&gt;Gridcoin&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Opprett en ny addresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Ny</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopier den valgte adressen til systemets utklippstavle</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopier</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Vis &amp;QR Kode</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Signer en melding for å vise at du eier en Gridcoin adresse</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signer &amp; send melding</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verifiser meldingen for å sjekke om den er signert med en gitt Gridcon adresse</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifiser en melding</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Slett den valgte adressen fra listen.</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Adressebok</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Dette er dine Gridcoin adresser for mottak av betalinger. Ved å gi forskjellige adresser til hver sender kan du holde oversikt over hvem som gjør betalinger til deg.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopier &amp;Merkelapp</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Eksporter Adressebok</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Feil under eksportering</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kunne ikke skrive til filen %1</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Merkelapp</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen merkelapp)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog for Adgangsfrase</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Angi adgangsfrase</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Ny adgangsfrase</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Gjenta ny adgangsfrase</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Angi en adgangsfrase for lommeboken.&lt;br/&gt; Venligst velg en frase med ti eller mer tilfeldige karakterer&lt;b&gt;, eller&lt;b&gt; åtte eller flere ord.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Krypter lommebok</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Denne operasjonen krever adgangsfrasen til lommeboken for å låse den opp.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Lås opp lommebok</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Endre adgangsfrase</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Skriv inn gammel og ny adgangsfrase for lommeboken.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bekreft kryptering av lommebok</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Advarsel: Hvis krypterer lommeboken din og mister passfrasen mister du tilgangen til &lt;b&gt;ALLE myntene din&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Er du sikker på at du vil kryptere lommeboken?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Lommebok kryptert</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin vil nå lukke applikasjonen for å fullføre krypteringsprosessen. Husk at en fullt kryptert lommebok ikke kan hindre myntene dine fra å bli stjålet hvis datamaskinen din blir infisert av skadevare.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>VIKTIG: Tidligere sikkerhetskopier av din lommebok-fil, bør erstattes med den nylig genererte, krypterte filen, da de blir ugyldiggjort av sikkerhetshensyn så snart du begynner å bruke den nye krypterte lommeboken.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Kryptering av lommebok feilet</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Kryptering av lommebok feilet på grunn av en intern feil. Din lommebok ble ikke kryptert.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>De angitte adgangsfrasene er ulike.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Opplåsing av lommebok feilet</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Adgangsfrasen angitt for dekryptering av lommeboken var feil.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Adgangsfrase for lommebok endret.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Advarsel: Caps Lock er på !</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Lommebok</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oversikt</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vis generell oversikt over lommeboken</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Send mynter til Gridcoin adresse</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Motta</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Vis listen med adresser for å motta betalinger</translation>
    </message>
    <message>
        <source>&amp;History</source>
        <translation>&amp;Historie</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Vis transaksjonshistorikk</translation>
    </message>
    <message>
        <source>&amp;Favorites</source>
        <translation>&amp;Favoritter</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Endre listen med lagrede adresser og merkelapper</translation>
    </message>
    <message>
        <source>&amp;Block Explorer</source>
        <translation>&amp;Blokkjede-utforsker</translation>
    </message>
    <message>
        <source>Block Explorer</source>
        <translation>Blokkjede-utforsker</translation>
    </message>
    <message>
        <source>&amp;Exchange</source>
        <translation>&amp;Børs</translation>
    </message>
    <message>
        <source>Gridcoin rewards distributed computing with BOINC</source>
        <translation>Gridcoin belønner distribuert databehandling gjennom BOINC</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Avslutt applikasjonen</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Om Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Vis informasjon om Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Innstillinger...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Vis / Skjul</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Krypter Lommebok...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Endre Adgangsfrase...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Endre adgangsfrasen brukt for kryptering av lommebok</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Lås opp lommeboken</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Lås opp lommebok</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Lås Lommeboken</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Lås lommeboken</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signer &amp;melding...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifiser melding...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Eksporter...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporter dataene i nåværende fane til en fil</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Feilsøkingsvindu</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Åpne konsoll for feilsøk og diagnostikk</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Innstillinger</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>[testnet]</source>
        <translation>[testnett]</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Oppdatert</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Laster ned...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Sendt transaksjon</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Innkommende transaksjon</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently %1 </source>
        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;unlocked for staking only&lt;/b&gt;</source>
        <translation>&lt;b&gt;låst opp for innsats(staking) &lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;fully unlocked&lt;/b&gt;</source>
        <translation>&lt;b&gt;Helt låst opp&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for tiden &lt;b&gt;låst&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation>Backup Mislyktes</translation>
    </message>
    <message>
        <source>none</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>Scraper: waiting on wallet to sync.</source>
        <translation>Skraper: Venter på at lommeboken skal synkronisere.</translation>
    </message>
    <message>
        <source>Scraper: superblock not needed - inactive.</source>
        <translation>Skraper: Trenger ikke superblokk - Inaktiv.</translation>
    </message>
    <message>
        <source>Scraper: downloading and processing stats.</source>
        <translation>Scraper: Laster ned og prosesserer statistikk</translation>
    </message>
    <message>
        <source>Scraper: Convergence achieved, date/time %1 UTC. 
Project(s) excluded: %2. 
Scrapers included: %3. 
Scraper(s) excluded: %4. 
Scraper(s) not publishing: %5.</source>
        <translation>Skraper: Konvergens oppnådd, dato/tid %1 UTC.
Prosjekt(er) ekskludert: %2
Skraper(e) inkludert: %3
Skraper(e) ekskludert: %4
Skraper(e) ikke publisert: %5.</translation>
    </message>
    <message>
        <source>Scraper: Convergence achieved, date/time %1 UTC. 
 Project(s) excluded: %2.</source>
        <translation>Skraper: Konvergens oppnådd, dato/tid %1 UTC.
Prosjekt(er) ekskludert: %2.</translation>
    </message>
    <message>
        <source>Scraper: No convergence able to be achieved. Will retry in a few minutes.</source>
        <translation>Skraper: Kunne ikke oppå konvergens. Prøver igjen om noen minutter.</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Nettverksvarsel</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Mengde:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Beløp:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Avgift:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lav Utdata:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Totalt:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Veksel:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløp</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bekreftelser</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bekreftet</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merkelapp</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopier adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopier merkelapp</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløp</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopier transaksjons-ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopier mengde</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopier gebyr</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopier etter gebyr</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopier veksel</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nei</translation>
    </message>
    <message>
        <source>This label turns red, if the change is smaller than %1.

 This means a fee of at least %2 is required.</source>
        <translation>Denne merkelappen blir rød, viss endringen er mindre enn %1

Dette betyr at det trengs en avgift på minimum %2.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen merkelapp)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>endring fra %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(endring)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Rediger adresse</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Merkelapp</translation>
    </message>
    <message>
        <source>The label associated with this address book entry</source>
        <translation>Navnet assosiert med denne adressen</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresse</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Ny mottaksadresse</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Ny utsendingsadresse</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Rediger mottaksadresse</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Rediger utsendingsadresse</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Den oppgitte adressen "%1" er allerede i adresseboken.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kunne ikke låse opp lommeboken.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Generering av ny nøkkel feilet.</translation>
    </message>
</context>
<context>
    <name>GUIUtil::HelpMessageBox</name>
    <message>
        <source>version</source>
        <translation>versjon</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Bruk:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Hoved</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Nettverk</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Sett opp port ved hjelp av &amp;UPnP</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxyens port (f.eks. 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimerer vinduet istedenfor å avslutte applikasjonen når vinduet lukkes. Når dette er slått på avsluttes applikasjonen kun ved å velge avslutt i menyen.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Vis adresser i transaksjonslisten</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Vindu</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Bruk</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Vis kun ikon i systemkurv etter minimering av vinduet.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimer til systemkurv istedenfor oppgavelinjen</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimer ved lukking</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Visning</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Språk for brukergrensesnitt</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Enhet for visning av beløper:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Velg standard delt enhet for visning i grensesnittet og for sending av bitcoins.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>default</source>
        <translation>standardverdi</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Angitt proxyadresse er ugyldig.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Skjema</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Tilgjengelig:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>Din nåværende saldo</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Umoden:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totalt:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>Din nåværende saldo</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>QRCodeDialog</name>
    <message>
        <source>Label:</source>
        <translation>Merkelapp:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Melding:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Beløp:</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Lagre som...</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Klientversjon</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informasjon</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Oppstartstidspunkt</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Antall tilkoblinger</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokkjeden</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Nåværende antall blokker</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Tidspunkt for siste blokk</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Åpne</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsoll</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Nettverkstrafikk</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totalt</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Inn:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Ut:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Loggfil for feilsøk</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Tøm konsoll</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Estimert totalt antall blokker</translation>
    </message>
    <message>
        <source>&amp;Show</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Klientnavn</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Bruk opp og ned pil for å navigere historikken, og &lt;b&gt;Ctrl-L&lt;/b&gt; for å tømme skjermen.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Skriv &lt;b&gt;help&lt;/b&gt; for en oversikt over kommandoer.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Send Bitcoins</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Inndata...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automatisk valgte</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Utilstrekkelige midler!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Mengde:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Beløp:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Gebyr:</translation>
    </message>
    <message>
        <source>Low Output:</source>
        <translation>Lav Utdata:</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nei</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Etter Gebyr:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Send til flere enn en mottaker</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Legg til &amp;Mottaker</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Fjern &amp;Alt</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bekreft sending</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopier mengde</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløp</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopier gebyr</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Bekreft sending av bitcoins</translation>
    </message>
    <message>
        <source>Are you sure you want to send %1?</source>
        <translation>Er du sikker på du ønsker å sende %1?</translation>
    </message>
    <message>
        <source> and </source>
        <translation>og</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Adresse for mottaker er ugyldig.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Beløpen som skal betales må være over 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Beløpet overstiger saldo.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Totalbeløpet overstiger saldo etter at %1 transaksjonsgebyr er lagt til.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Duplikate adresser funnet. Kan bare sende én gang til hver adresse per operasjon.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(ingen merkelapp)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Beløp:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Betal &amp;Til:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Melding:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Merkelapp:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Lim inn adresse fra utklippstavlen</translation>
    </message>
    <message>
        <source>Choose address from address book</source>
        <translation>Velg adresse fra adresseboken</translation>
    </message>
    <message>
        <source>Remove this recipient</source>
        <translation>Fjern denne mottakeren</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Skriv inn en merkelapp for denne adressen for å legge den til i din adressebok</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signaturer - Signer / Verifiser en Melding</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Signer Melding</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Du kan signere meldinger med dine adresser for å bevise at du eier dem. Ikke signér vage meldinger da phishing-angrep kan prøve å lure deg til å signere din identitet over til andre. Signér kun fullt detaljerte utsagn som du er enig i.</translation>
    </message>
    <message>
        <source>Choose an address from the address book</source>
        <translation>Velg en adresse fra adresseboken</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Lim inn adresse fra utklippstavlen</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Skriv inn meldingen du vil signere her</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopier valgt signatur til utklippstavle</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Signer &amp;Melding</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Tilbakestill alle felter for meldingssignering</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Fjern &amp;Alt</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifiser Melding</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Angi adresse for signering, melding (vær sikker på at du kopierer linjeskift, mellomrom, tab, etc. helt nøyaktig) og signatur under for å verifisere meldingen. Vær forsiktig med at du ikke gir signaturen mer betydning enn det som faktisk står i meldingen, for å unngå å bli lurt av såkalte "man-in-the-middle" angrep.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Tilbakestill alle felter for meldingsverifikasjon</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Klikk "Signer Melding" for å generere signatur</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Angitt adresse er ugyldig.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Vennligst sjekk adressen og prøv igjen.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Angitt adresse refererer ikke til en nøkkel.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Opplåsing av lommebok ble avbrutt.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Privat nøkkel for den angitte adressen er ikke tilgjengelig.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Signering av melding feilet.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Melding signert.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Signaturen kunne ikke dekodes.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Vennligst sjekk signaturen og prøv igjen.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Signaturen passer ikke til meldingen.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Verifikasjon av melding feilet.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Melding verifisert.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Åpen til %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/frakoblet</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/ubekreftet</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 bekreftelser</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, har ikke blitt kringkastet uten problemer enda.</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kilde</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Fra</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>ukjent</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Til</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>egen adresse</translation>
    </message>
    <message>
        <source>label</source>
        <translation>merkelapp</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Kredit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>ikke akseptert</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksjonsgebyr</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Nettobeløp</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløp</translation>
    </message>
    <message>
        <source>true</source>
        <translation>sann</translation>
    </message>
    <message>
        <source>false</source>
        <translation>usann</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Transaksjonsdetaljer</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Her vises en detaljert beskrivelse av transaksjonen</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløp</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Åpen til %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Ubekreftet</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Bekreftet (%1 bekreftelser)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Generert men ikke akseptert</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Mottatt med</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Mottatt fra</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendt til</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betaling til deg selv</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Transaksjonsstatus. Hold muspekeren over dette feltet for å se antall bekreftelser.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Dato og tid for da transaksjonen ble mottat.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Type transaksjon.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Mottaksadresse for transaksjonen</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Beløp fjernet eller lagt til saldo.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Denne uken</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Denne måneden</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Forrige måned</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Dette året</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Intervall...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Mottatt med</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Sendt til</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Til deg selv</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Utvunnet</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Andre</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimumsbeløp</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopier adresse</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopier merkelapp</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopiér beløp</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopier transaksjons-ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Rediger merkelapp</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Vis transaksjonsdetaljer</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bekreftet</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merkelapp</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Beløp</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Kunne ikke skrive til filen %1</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Intervall:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>til</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Sending...</source>
        <translation>Sender...</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>En feil oppstod under oppsettet av RPC port %u for IPv6, tilbakestilles til IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>En feil oppstod ved opprettelse av RPC port %u for lytting: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Bruk:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>List opp kommandoer</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Vis hjelpetekst for en kommando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Advarsel: -paytxfee er satt veldig høyt! Dette er transaksjonsgebyret du betaler når du sender transaksjoner.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Advarsel: wallet.dat korrupt, data reddet! Original wallet.dat lagret som wallet.{timestamp}.bak i %s; hvis din saldo eller dine transaksjoner ikke er korrekte bør du gjenopprette fra en backup.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Advarsel: Feil ved lesing av wallet.dat! Alle taster lest riktig, men transaksjon dataene eller adresse innlegg er kanskje manglende eller feil.</translation>
    </message>
    <message>
        <source>Error: Transaction creation failed  </source>
        <translation>Feil: Opprettelse av transaksjonen mislyktes</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Kunne ikke lytte på noen port. Bruk -listen=0 hvis det er dette du vil.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>For å bruke %s opsjonen</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Du må sette rpcpassword=&lt;passord&gt; i konfigurasjonsfilen:
%s
Hvis filen ikke finnes, opprett den med leserettighet kun for eier av filen.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Ugyldig beløp for -paytxfee=&lt;beløp&gt;: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Lommeboken %s holder til utenfor data mappen %s.</translation>
    </message>
    <message>
        <source>Verifying database integrity...</source>
        <translation>Verifiserer databasens integritet...</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat korrupt, bergning feilet</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Ugyldig -proxy adresse: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Kunne ikke slå opp -bind adresse: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Kunne ikke slå opp -externalip adresse: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Feil ved lasting av wallet.dat: Lommeboken er skadet</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Feil ved lasting av wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Laster adresser...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Kan ikke binde til %s på denne datamaskinen (bind returnerte feil %d, %s)</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Sender...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Ugyldig beløp</translation>
    </message>
    <message>
        <source>Warning: Disk space is low!</source>
        <translation>Advarsel: Lite lagringsplass!</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Ukjent nettverk angitt i -onlynet '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Utilstrekkelige midler</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Laster blokkindeks...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Laster lommebok...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Kan ikke skrive standardadresse</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Leser gjennom...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Ferdig med lasting</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
</TS>